bodhi-shell — bodhi 4.0.0 documentation

# bodhi-shell

## Synopsis

`bodhi-shell`

## Description

`bodhi-shell` is used to run a Python shell initialized with Bodhi models.

## Options

`--help`

> Show help text and exit.

`--version`

> Show version and exit.

## Help

If you find bugs in Bodhi (or in this man page), please feel free to file a bug report or a pull request:

    https://github.com/fedora-infra/bodhi

Bodhi’s documentation is available online: https://bodhi.fedoraproject.org/docs